@@ -22,7 +22,6 @@ import tempfile
 import unittest
 import codecs
 
-from lazygal import py2compat
 from lazygal.sourcetree import Directory
 from lazygal.generators import Album
 
@@ -39,9 +38,17 @@ LOCALES_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__),
 gettext.install('lazygal', LOCALES_PATH)
 
 
-# Init quiet logging
+# Init logging
 import logging
 logging.basicConfig(format='%(message)s', level=logging.ERROR)
+logger = logging.getLogger()
+logger.setLevel(logging.INFO)
+try:
+    debug = os.environ['DEBUG']
+except KeyError:
+    logger.setLevel(logging.ERROR)
+else:
+    logger.setLevel(logging.DEBUG)
 
 
 def has_symlinks():
@@ -61,7 +68,7 @@ class LazygalTest(unittest.TestCase):
     def get_working_path(self):
         new_wd = tempfile.mkdtemp()
         self.__workdirs.append(new_wd)
-        return py2compat.u(new_wd)
+        return new_wd
 
     def get_sample_path(self, sample):
         return os.path.join(SAMPLES_DIR, sample)
@@ -88,7 +95,7 @@ class LazygalTest(unittest.TestCase):
 class LazygalTestGen(LazygalTest):
 
     def setUp(self, album=True):
-        super(LazygalTestGen, self).setUp()
+        super().setUp()
 
         self.tmpdir = self.get_working_path()
         self.source_dir = os.path.join(self.tmpdir, 'src')
@@ -125,18 +132,18 @@ def my_import(name):
 
 def sample_album(outdir):
     d = os.path.normpath(outdir)
-    os.makedirs(d)
+    os.makedirs(d, exist_ok=True)
     sample = LazygalTest()
     sample.add_img(d, 'root.jpg')
 
     flowers = os.path.join(d, 'flower')
-    os.makedirs(flowers)
+    os.makedirs(flowers, exist_ok=True)
     sample.add_img(flowers, 'coquelicot.jpg')
     sample.add_img(flowers, 'rose.jpg')
     sample.add_video(flowers, 'nature.mov')
 
     beers = os.path.join(d, 'beers')
-    os.makedirs(beers)
+    os.makedirs(beers, exist_ok=True)
     sample.add_img(beers, 'guinness.jpg')
     sample.add_img(beers, 'kilkenny.jpg')
 
